#ifndef HARKIO_HARKCONFIG_WRITABLE_HPP_
#define HARKIO_HARKCONFIG_WRITABLE_HPP_

#include <harkio2/InvalidHarkFile.hpp>

/** @file Writable.hpp
 * @brief Writable interface definition.
 */

namespace harkio2
{
namespace harkconfig
{

class HarkConfigFileWriter;

/** @brief Writable interface.
 * Data structures which can be written to a file (e.g. HarkConfigFile, TSPListFile1_0, TSPListFile2_0,...)
 * should implement this interface.
 */
class Writable
{
public:
    /// @brief Virtual destructor for derivation.
    virtual ~Writable() {}

    /** @brief Writes a data structure using the specified writer.
     * @param writer A writer object.
     */
    virtual void Write(HarkConfigFileWriter& writer) const throw (harkio2::InvalidHarkFile) = 0;
};

}
}

#endif // HARKIO_HARKCONFIG_WRITABLE_HPP_

